#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from pyams_i18n.schema import I18nTextField, I18nTextLineField
from pyams_sequence.interfaces import IInternalReference

from onf_website import _


class IONFNavigationPortletRendererSettings(Interface):
    """ONF navigation portlet renderer settings interface"""

    header = I18nTextField(title=_("Header"),
                           description=_("Menu header displayed by front-office template"),
                           required=False)


class IONFNavigationPortletRendererSettingsWithSubtitle(IONFNavigationPortletRendererSettings):

    subtitle = I18nTextLineField(title=_("Subtitle"),
                                 description=_("Menu subtitle displayed by front-office template"),
                                 required=False)


class IONFExternalNavigationPortletRendererSettings(Interface):
    """ONF external navigation portlet renderer settings interface"""

    button_label = I18nTextLineField(title=_("Button label"),
                                     description=_("Label of the navigation button displayed by "
                                                   "front-office template"),
                                     required=False)


class IONFCatalogNavigationPortletRendererSettings(IInternalReference):
    """ONF catalog navigation portlet renderer settings interface"""

    teaser = I18nTextField(title=_("Teaser"),
                           description=_("Short text displayed before catalog items"),
                           required=False)

    button_label = I18nTextLineField(title=_("Button label"),
                                     description=_("Label of the navigation button displayed by "
                                                   "front-office template if the target is published"),
                                     required=False)


class IONFCarouselNavigationPortletRendererSettings(Interface):
    """ONF carousel navigation portlet renderer settings interface"""

    teaser = I18nTextField(title=_("Teaser"),
                           description=_("Short text displayed above carousel"),
                           required=False)
